DLink.DES3xxx
=============

====== =================================
Vendor `D-Link <http://www.dlink.com/>`_
OS     DES
====== =================================

DLink.DES3xxx profile supports various DLink DES3xxx ethernet switches

Tested Equipment
----------------
.. supported:: DLink.DES3xxx

